var Validator, https, url;
url = require('url');
https = require('https');
Validator = (function() {
  function Validator(ssoHost, serverBaseURL) {
    this.ssoHost = ssoHost;
    this.serverBaseURL = serverBaseURL;
  }
  Validator.prototype.validate = function(request, ticket, callback) {
    var get, parsedURL, resolvedURL, service;
    resolvedURL = url.resolve(this.serverBaseURL, request.url);
    parsedURL = url.parse(resolvedURL, true);
    delete parsedURL.query.ticket;
    delete parsedURL.search;
    service = url.format(parsedURL);
    get = https.get({
      host: this.ssoHost,
      path: url.format({
        pathname: '/validate',
        query: {
          ticket: ticket,
          service: service
        }
      })
    }, function(response) {
      var body;
      response.setEncoding('utf8');
      body = '';
      response.on('data', function(chunk) {
        return body += chunk;
      });
      return response.on('end', function() {
        var lines, user;
        lines = body.split('\n');
        if (lines.length >= 1) {
          if (lines[0] === 'no') {
            callback(null, null);
            return;
          } else if (lines[0] === 'yes' && lines.length >= 2) {
            user = {
              id: lines[1]
            };
            callback(user, null);
            return;
          }
        }
        callback(null, new Error('The response from the server was bad'));
      });
    });
    get.on('error', function(e) {
      console.error(e);
      return callback(null, e);
    });
  };
  return Validator;
})();
exports.getMiddleware = function(ssoHost, serverBaseURL, options) {
  var loginURL, ssoBaseURL, validateURL, validator;
  ssoBaseURL = 'https://' + ssoHost;
  loginURL = ssoBaseURL + '/login';
  validateURL = ssoBaseURL + '/validate';
  validator = new Validator(ssoHost, serverBaseURL);
  return function(req, res, next) {
    var redirectURL, service, ticket, user, _ref;
    if (((_ref = req.session) != null ? _ref.authenticatedUser : void 0) != null) {
      req.authenticatedUser = req.session.authenticatedUser;
      next();
      return;
    }
    ticket = req.param('ticket');
    if (ticket != null) {
      return user = validator.validate(req, ticket, function(user, error) {
        if (req.session != null) {
          req.session.authenticatedUser = user;
        } else {
          req.authenticatedUser = user;
        }
        next();
      });
    } else {
      redirectURL = url.parse(loginURL, true);
      service = serverBaseURL + req.url;
      redirectURL.query.service = service;
      return res.redirect(url.format(redirectURL));
    }
  };
};